pub fn split_unquoted_whitespace(src: &str) -> SplitUnquotedChar<'_> ⓘExpand description
Return a new iterator of the the whitespace separated tokens of the given string, taking quotes into account
pub fn split_unquoted_whitespace(src: &str) -> SplitUnquotedChar<'_> ⓘReturn a new iterator of the the whitespace separated tokens of the given string, taking quotes into account